@@ -10,9 +10,19 @@ pub enum OrderBy {
     Desc,
 }
 
-impl Into<Order> for OrderBy {
-    fn into(self) -> Order {
-        if self == OrderBy::Asc {
+// impl Into<Order> for OrderBy {
+//     fn into(self) -> Order {
+//         if self == OrderBy::Asc {
+//             Order::Ascending
+//         } else {
+//             Order::Descending
+//         }
+//     }
+// }
+
+impl From<OrderBy> for Order {
+    fn from(order_by: OrderBy) -> Order {
+        if order_by == OrderBy::Asc {
             Order::Ascending
         } else {
             Order::Descending
@@ -25,4 +35,4 @@ impl Into<Order> for OrderBy {
 pub enum Network {
     Mainnet,
     Testnet,
-}
\ No newline at end of file
+}
