@@ -1,34 +1,32 @@
 use schemars::JsonSchema;
 use serde::{Deserialize, Serialize};
 
-use cosmwasm_std::{HumanAddr, Uint128};
+use cosmwasm_std::Uint128;
 
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
-pub struct InitMsg {
-    pub owner: HumanAddr,        // mirror gov contract
-    pub mirror_token: HumanAddr, // mirror token address
-    pub spend_limit: Uint128,    // spend limit per each `spend` request
+pub struct InstantiateMsg {
+    pub owner: String,        // mirror gov contract
+    pub mirror_token: String, // mirror token address
+    pub spend_limit: Uint128, // spend limit per each `spend` request
 }
 
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
 #[serde(rename_all = "snake_case")]
-pub enum HandleMsg {
+pub enum ExecuteMsg {
     UpdateConfig {
-        owner: Option<HumanAddr>,
+        owner: Option<String>,
         spend_limit: Option<Uint128>,
     },
     Spend {
-        recipient: HumanAddr,
+        recipient: String,
         amount: Uint128,
     },
 }
 
-
 /// We currently take no arguments for migrations
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
 pub struct MigrateMsg {}
 
-
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
 #[serde(rename_all = "snake_case")]
 pub enum QueryMsg {
@@ -38,7 +36,7 @@ pub enum QueryMsg {
 // We define a custom struct for each query response
 #[derive(Serialize, Deserialize, Clone, Debug, PartialEq, JsonSchema)]
 pub struct ConfigResponse {
-    pub owner: HumanAddr,
-    pub mirror_token: HumanAddr,
+    pub owner: String,
+    pub mirror_token: String,
     pub spend_limit: Uint128,
 }
